@@ -258,7 +258,9 @@ namespace giac {
   // step by step utilities
   // poi=point of interest, tvi=table of variation
   // asym=list of asymptotes, crit=critical points, inflex=inflection points
-  int step_func(const gen & f,const gen & x,gen & xmin,gen&xmax,vecteur & poig,vecteur & tvi,gen & periode,vecteur & asym,vecteur & parab,vecteur & crit,vecteur & inflex,bool printtvi,bool exactlegende,GIAC_CONTEXT,bool do_inflex=true);
+  // bit 0 of do_inflex_tabsign = set to 1 for inflexion (valid for tabvar)
+  // bit 1 of do_inflex_tabsign = set to 1 for tabsign, 0 for tabvar
+  int step_func(const gen & f,const gen & x,gen & xmin,gen&xmax,vecteur & poig,vecteur & tvi,gen & periode,vecteur & asym,vecteur & parab,vecteur & crit,vecteur & inflex,bool printtvi,bool exactlegende,GIAC_CONTEXT,int do_inflex_tabsign=1);
   extern const unary_function_ptr * const  at_tabvar;
   int step_param(const gen & f,const gen & g,const gen & t,gen & tmin,gen&tmax,vecteur & poi,vecteur & tvi,bool printtvi,bool exactlegende,GIAC_CONTEXT);
   // translate HTML Xcas for Firefox link to a giac list of commands
@@ -290,8 +292,21 @@ namespace giac {
   extern const unary_function_ptr * const  at_draw_string ;
   extern const unary_function_ptr * const  at_dtype ;
   extern const unary_function_ptr * const  at_rgb ;
+  extern const unary_function_ptr * const  at_prediction;
+  extern const unary_function_ptr * const  at_prediction95;
+  extern const unary_function_ptr * const  at_confidence;
   gen _rgb(const gen & args,GIAC_CONTEXT);
   gen _charpoly(const gen & args,GIAC_CONTEXT);
+  void draw_rectangle(int x, int y, int width, int height, unsigned short color,GIAC_CONTEXT);
+  void draw_polygon(std::vector< std::vector<int> > & v1,int color,GIAC_CONTEXT);
+  void draw_filled_polygon(std::vector< std::vector<int> > &L,int xmin,int xmax,int ymin,int ymax,int color,GIAC_CONTEXT);
+  void draw_line(int x1, int y1, int x2, int y2, int color,GIAC_CONTEXT);
+  void set_pixel(int x,int y,int c,GIAC_CONTEXT);
+  void draw_circle(int xc,int yc,int r,int color,bool q1,bool q2,bool q3,bool q4,GIAC_CONTEXT);
+  void draw_filled_circle(int xc,int yc,int r,int color,bool left,bool right,GIAC_CONTEXT);
+  void draw_arc(int xc,int yc,int rx,int ry,int color,double t1, double t2,bool q1,bool q2,bool q3,bool q4,GIAC_CONTEXT);
+  void draw_arc(int xc,int yc,int rx,int ry,int color,double theta1, double theta2,GIAC_CONTEXT);
+  void draw_filled_arc(int x,int y,int rx,int ry,int theta1_deg,int theta2_deg,int color,int xmin,int xmax,int ymin,int ymax,bool segment,GIAC_CONTEXT);
 
   std::string fetch(const std::string & url);
 #ifndef NO_NAMESPACE_GIAC
